@echo off

REM *******************************************************
REM		   Astrocade Compile and Run (ACAR)
REM 
REM This batch file assembles an Astrocade source file and
REM runs it in MAME. It also allows special functions via
REM calling it with parameters (see code remarks below).
REM
REM NOTE: There is no error checking so you have to stop
REM the process manually if something goes wrong.
REM
REM *******************************************************

echo Astrocade Compile and Run (ACAR)
echo Version: 20181221 by David E. Turner AKA Commander Dave
echo          dave@commanderdave.com

REM *******************************************************
REM Set the paths and filenames. It is recommended you put the
REM base directory under the c:\users\%username% directory.
REM
REM	Hard_Drive	     Which HDD letter you are using (ex. C:)
REM	Base_Directory	     Where the first level directory is located.
REM	Source_Path	     Where your source file is located
REM	Source_Name	     The source file name (ex. Astrocade_Disassembly.asm)	
REM	Zmac_Path	     Points to the Zmac compiler directory
REM	Astrocade_MAME_Path  Points to the MAME directory
REM	Astrocade_MAME_ROMs  Points to the MAME ROM directory
REM	Utilities_Path	     Location of utilities like fsplit & Hex2Bin
REM     Scratch_Area	     Where the batch files do their work
REM	Original_ROM_Path    Points to original ROMs
REM *******************************************************

SET HardDrive=C:
SET Base_Directory=%HardDrive%\Users\%username%\Google_Drive\APD


SET Source_Path=%Base_Directory%\Astrocade
SET Source_Name=Astrocade_Program
SET Zmac_Path=%Base_Directory%\_Programs\zmac
SET Astrocade_MAME_Path=%Base_Directory%\_Programs\MAME
SET Astrocade_MAME_ROMs=%Astrocade_MAME_Path%\roms\astrocde
SET Utilities_Path=%Base_Directory%\_Programs\Utilities
SET Scratch_Area=%Utilities_Path%\_Scratch_Area
SET Original_ROM_Path=%Base_Directory%\_Programs\ROMs\astrocde

REM *******************************************************
REM Check input to batch file to see if it is a special case.
REM	Empty = Compile Astrocade as normal
REM	1 = Just go run Astrocade with no modifications to ROMs
REM	2 = Reset the MAME ROMs to original defaults.
REM *******************************************************

IF [%1]==[] GOTO :compile_Astrocade
IF %1==1 GOTO :run_Astrocade
IF %1==2 GOTO :reset_roms

:compile_Astrocade

REM *******************************************************
REM Clear the scratch area and change the directory
REM to where the action is...
REM *******************************************************

del /Q %Scratch_Area%\*.*
cd /D %Scratch_Area%

REM *******************************************************
REM Zmac has many environment and command line options. 
REM This will provide a bit of what the selected options 
REM do. For better descriptions, see the Zmac manual.
REM
REM The simplified Zmac command line is:
REM   zmac -i m -h -o out-file -x list-file input-file-name
REM
REM Options:
REM	-h	Output is in Intel Hex format
REM	-o	Output file (in our case Intel Hex format)
REM	-x	Listing file
REM	-i	Don't list include files
REM	-m	List macro expansions	
REM 
REM The input file name will be taken from the Source_Name 
REM variable and the output will be in the form of the 
REM filename with the extensions .hex and .lst.
REM *******************************************************

echo. 
echo --} Compiling %Source_Name% 

cd %Source_Path%\Include_Files
%Zmac_Path%\zmac.exe -i -m -h -o %Source_Path%\%Source_Name%.hex -x %Source_Path%\%Source_Name%.lst %Source_Path%\%Source_Name%.asm  

echo --} Converting .hex to .bin 

%Utilities_Path%\hex2bin\hex2bin %Source_Path%\%Source_Name%.hex >NUL 2>NUL

echo --} Moving ROM files to MAME area

move %Source_Path%\%Source_Name%.bin %Astrocade_MAME_ROMs%\%Source_Name%.bin >NUL
echo.
echo --------------------------------------------------
echo --- Press any key to run MAME with new program ---
echo --------------------------------------------------
echo.
pause

REM *******************************************************
REM Run Astrocade!
REM *******************************************************
:run_Astrocade
cd /D %Astrocade_MAME_Path%
mame64 astrocde -cart %Astrocade_MAME_ROMs%\%Source_Name%.bin -debug -nofilter
GOTO:eof

REM *******************************************************
REM Reset Astrocade ROMs to their defaults
REM *******************************************************

:reset_roms
cd /D %Astrocade_MAME_ROMs%
REM Preserve the user's program binary
copy /Y %Source_Name%.bin %Original_ROM_Path% >NUL
del /Q *.* >NUL
copy /Y %Original_ROM_Path%\*.* . >NUL
echo.
echo --} Astrocade ROMs have been reset to defaults
echo --} Your Astrocade_Program.bin file was preserved.
echo.
pause
GOTO:eof