@echo off

REM *******************************************************
REM		   GORF Compile and Run (GCAR)
REM 
REM This batch file assembles the Gorf source file and
REM verifies that the binaries are identical by running
REM it in MAME. It also allows special functions via
REM calling it with parameters (see code remarks below).
REM
REM NOTE: There is no error checking so you have to stop
REM the process manually if something goes wrong.
REM
REM *******************************************************

echo Gorf Compile and Run (ACAR)
echo Version: 20181221 by David E. Turner AKA Commander Dave
echo          dave@commanderdave.com

REM *******************************************************
REM Set the paths and filenames. It is recommended you put the
REM base directory under the c:\users\%username% directory.
REM
REM	Hard_Drive	   Which HDD letter you are using (ex. C:)
REM	Base_Directory	   Where the first level directory is located.
REM	Source_Path	   Where your source file is located
REM	Source_Name	   The source file name (ex. Gorf_Disassembly.asm)	
REM	Zmac_Path	   Points to the Zmac compiler directory
REM	Gorf_MAME_Path	   Points to the MAME directory
REM	Gorf_MAME_ROMs	   Points to the MAME ROM directory
REM	Utilities_Path	   Location of utilities like fsplit & Hex2Bin
REM     Scratch_Area	   Where the batch files do their work
REM	Original_ROM_Path  Points to original ROMs
REM *******************************************************

REM ---} Change the two lines below to suit your taste {---
REM ---} BE SURE not to have any spaces before or after the path or drive!

SET HardDrive=C:
SET Base_Directory=%HardDrive%\Users\%username%\Google_Drive\APD


SET Source_Path=%Base_Directory%\Gorf\Disassembly
SET Source_Name=Gorf_Disassembly
SET Zmac_Path=%Base_Directory%\_Programs\Zmac
SET MAME_Path=%Base_Directory%\_Programs\MAME
SET MAME_ROMs=%MAME_Path%\roms\gorf
SET Utilities_Path=%Base_Directory%\_Programs\Utilities
SET Scratch_Area=%Utilities_Path%\_Scratch_Area
SET Original_ROM_Path=%Base_Directory%\_Programs\ROMs\gorf

REM *******************************************************
REM Check input to batch file to see if it is a special case.
REM	Empty = Compile Gorf as normal
REM	1 = Just go run Gorf with no modifications to ROMs
REM	2 = Reset the MAME ROMs to original defaults.
REM *******************************************************

IF [%1]==[] GOTO :compile_gorf	
IF %1==1 GOTO :run_gorf
IF %1==2 GOTO :reset_roms

:compile_gorf

REM *******************************************************
REM Clear the scratch area and change the directory
REM to where the action is...
REM *******************************************************

del /Q %Scratch_Area%\*.*
cd /D %Scratch_Area%

REM *******************************************************
REM Zmac has many environment and command line options. 
REM This will provide a bit of what the selected options 
REM do. For better descriptions, see the Zmac manual.
REM
REM The simplified Zmac command line is:
REM   zmac -h -o out-file -x list-file input-file-name
REM
REM Options:
REM   -h       Output is in Intel Hex format
REM   -o       Output file (in our case Intel Hex format)
REM   -x       Listing file
REM 
REM The input file name will be taken from the Source_Name 
REM variable and the output will be in the form of the 
REM filename with the extensions .hex and .lst.
REM *******************************************************

echo. 
echo --} Compiling %Source_Name% 

%Zmac_Path%\zmac.exe -h -o %Source_Path%\%Source_Name%.hex -x %Source_Path%\%Source_Name%.lst %Source_Path%\%Source_Name%.asm  

echo --} Converting .hex to .bin 

copy %Source_Path%\%Source_Name%.hex %Source_Name%.hex >NUL
%Utilities_Path%\hex2bin\hex2bin %Source_Name%.hex 2>NUL >NUL

REM *******************************************************
REM At this point, the source has been assembled in to one
REM large binary file and needs to be split into it's 
REM eight parts: 
REM gorf-a, gorf-b, gorf-c, gorf-d 
REM gorf-e, gorf-f, gorf-g, gorf-h
REM *******************************************************

echo --} Splitting Binary File 

%Utilities_Path%\fsplit\fsplit.exe -split 4 kb %Source_Name%.bin >NUL

REM *******************************************************
REM Due to a limitation in the splitting program, we have
REM to remove some unnecessary files. The middle four 
REM files are just FF padding put in by the fsplit program.
REM Unforutnaly, there is no option for preventing this (yet)
REM *******************************************************

echo --} Removing unnecessary files created by split program 

del Gorf_Disassembly_05*.bin >NUL
del Gorf_Disassembly_06*.bin >NUL
del Gorf_Disassembly_07*.bin >NUL
del Gorf_Disassembly_08*.bin >NUL

REM *******************************************************
REM Now we have to rename the assembled binaries 
REM to match Gorf ROMS required by MAME
REM *******************************************************

echo --} Renaming binary files for MAME 
 
rename Gorf_Disassembly_01*.bin gorf-a.bin >NUL
rename Gorf_Disassembly_02*.bin gorf-b.bin >NUL
rename Gorf_Disassembly_03*.bin gorf-c.bin >NUL
rename Gorf_Disassembly_04*.bin gorf-d.bin >NUL
rename Gorf_Disassembly_09*.bin gorf-e.bin >NUL
rename Gorf_Disassembly_10*.bin gorf-f.bin >NUL
rename Gorf_Disassembly_11*.bin gorf-g.bin >NUL
rename Gorf_Disassembly_12*.bin gorf-h.bin >NUL

echo --} Moving ROM files to MAME area

move gorf-?.bin "%MAME_ROMs%" >NUL
echo.
echo --------------------------------------------------
echo --- Press any key to run MAME with new program ---
echo --------------------------------------------------
echo.
pause

REM *******************************************************
REM Run Gorf!
REM *******************************************************
:run_gorf
cd /D %MAME_Path%
mame64.exe -debug gorf
GOTO:eof

REM *******************************************************
REM Reset Gorf ROMs to their defaults
REM *******************************************************

:reset_roms
cd /D %MAME_ROMs%
del gorf*.bin >NUL 2>NUL
del sc01a.bin >NUL 2>NUL
copy %Original_ROM_Path%\Gorf-a.bin Gorf-a.bin >NUL
copy %Original_ROM_Path%\Gorf-b.bin Gorf-b.bin >NUL
copy %Original_ROM_Path%\Gorf-c.bin Gorf-c.bin >NUL
copy %Original_ROM_Path%\Gorf-d.bin Gorf-d.bin >NUL
copy %Original_ROM_Path%\Gorf-e.bin Gorf-e.bin >NUL
copy %Original_ROM_Path%\Gorf-f.bin Gorf-f.bin >NUL
copy %Original_ROM_Path%\Gorf-g.bin Gorf-g.bin >NUL
copy %Original_ROM_Path%\Gorf-h.bin Gorf-h.bin >NUL
copy %Original_ROM_Path%\sc01a.bin sc01a.bin   >NUL
echo --} Gorf ROMs have been reset to defaults
echo.
pause
GOTO:eof