@echo off

REM *******************************************************
REM		Setup Arcade Programming Environment 
REM 
REM The purpose of this batch file is to install the 
REM necessary programs and settings for the arcade programming
REM environment. By having the user download and install some
REM of the programs, it saves space when downloading the arcade
REM programming environment. Here are the programs and settings
REM that this batch file currently handles:
REM 
REM 	MAME - https://www.mamedev.org/release.html
REM 	ROMs - Included
REM 	PSPad - https://www.fosshub.com/PSPad.html
REM 	Astrocade syntax file for PSPad - Included
REM
REM Usage:
REM 	1. Download and copy the MAME install .EXE and the
REM        PSPad PORTABLE .ZIP file to the 
REM        Arcade_Programming\_Programs directory.
REM     2. Run the Install.bat file
REM
REM NOTE: There is very little error checking built in. :-o
REM
REM *******************************************************

echo Name:    Setup Arcade Programming Environment
echo Version: 20181223 by David E. Turner AKA Commander Dave
echo Email:   dave@commanderdave.com

REM *******************************************************
REM Install MAME from .exe file
REM *******************************************************
 
echo. 
echo --} Installing MAME

REM Find & store the name of the MAME install file 
FOR /F %%P IN ('dir /b  /a-d mame*.exe') DO set MFN=%%P > NUL
IF NOT DEFINED MFN GOTO :mame_missing
xcopy .\%MFN% ..\MAME /Y /Q > NUL
..\MAME\%MFN% -o -y > NUL
del /Q ..\MAME\%MFN% > NUL

echo --} Moving ROMs into MAME directory
xcopy ..\ROMs\*.* ..\MAME\roms /S /E /Y /Q > NUL
echo --} End of MAME install. 

REM *******************************************************
REM Install PSPad from .zip file
REM *******************************************************

echo --} Installing PSPad Editor

REM Find & store the name of the PSPad Zip file
FOR /F %%P IN ('dir /b  /a-d pspad*.zip') DO set PFN=%%P
IF NOT DEFINED PFN GOTO :psp_missing
..\Utilities\unzip -o -qq %PFN% -d ..\PSPad 2> NUL
echo --} Moving Z80 syntax file into PSPad directory
xcopy .\Z80.INI ..\PSPad\syntax /S /E /Y /Q  >NUL
echo --} End of PSPad install. 
pause

GOTO:eof

:mame_missing
echo.
echo MAME install file missing! Exiting...
pause
GOTO:eof

:psp_missing
echo.
echo PSPad install file missing! Exiting...
pause
GOTO:eof